Module types

Module types 

Contains the control types and types for the robot and gripper state

Structs

CartesianPose
Describes the desired cartesian pose that will be send to the robot.
GripperState
Describes the state of the Gripper at a certain point in time.
JointPositions
Describes the desired joint positions that will be send to the robot.
RobotState
Describes the State of the Robot at a certain point in time.
Torques
Describes the desired Torques that will be send to the robot.

Type Aliases

Matrix7
A Matrix with 7 rows and 7 columns
Vector7
A Vector with 7 entries