pub struct JointPositions {
pub joint_positions: Vector7,
pub is_finished: bool,
}Expand description
Describes the desired joint positions that will be send to the robot.
Fields
joint_positions: Vector7desired joint positions
is_finished: boolwhether the robot should stop the control loop after this message.