pub trait RealSetup {
// Provided methods
fn setup_real(&mut self) { ... }
fn setup_camera(&mut self) { ... }
fn get_camera_image(&mut self) -> RgbaImage { ... }
}Expand description
A trait which contains methods for handling the real robot. All methods have a default implementation, so you do not have to implement them if you do not need them.
Provided Methods
Sourcefn setup_real(&mut self)
fn setup_real(&mut self)
This method runs directly on calling Experiment::new. You can use
it to run specific code which is only needed when using the real hardware.
Sourcefn setup_camera(&mut self)
fn setup_camera(&mut self)
Runs directly after setup_real and is intended for setting up the camera.
Sourcefn get_camera_image(&mut self) -> RgbaImage
fn get_camera_image(&mut self) -> RgbaImage
determine how you want to get the camera image with this method.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".