Contains the control types and types for the robot and gripper state
Structs
- Cartesian
Pose - Describes the desired cartesian pose that will be send to the robot.
- Gripper
State - Describes the state of the Gripper at a certain point in time.
- Joint
Positions - Describes the desired joint positions that will be send to the robot.
- Robot
State - Describes the State of the Robot at a certain point in time.
- Torques
- Describes the desired Torques that will be send to the robot.